@@ -255,7 +255,7 @@ with a HASH ref for each result. An example of the item array's content are show
 
 =head1 AUTHOR
 
-Trizen, C<< <trizenx at gmail.com> >>
+Trizen, C<< <echo dHJpemVuQHByb3Rvbm1haWwuY29tCg== | base64 -d> >>
 
 
 =head1 SUPPORT
